Provides a interface to Aliscore, in order to remove problematic regions of a DNA sequence alignment.
aliscore(x, gaps = "5state", w = 6, r, t, l, s, o, exec)A matrix of class "DNAbin".
DNA sequences of class DNAbin.
A vector of mode "character" indicating how gaps shall be
treated: as "5state" or as "ambiguous".
An integer giving the size of the sliding window.
An integer giving the number of random pairwise sequence
comparisons; defaults to 4 * N.
Not yet implemented.
Not yet implemented.
Not yet implemented.
A vector of mode "character" containing outgroup taxon names.
A character string, giving the path to the Aliscore script.
Misof, B. and K. Misof. 2009. A Monte Carlo approach successfully identifies randomness in multiple sequence alignments: a more objective means of data exclusion. Syst. Biol. 58: 21--34.
Kueck, P., K. Meusemann, J. Dambach, B. Thormann, B.M. von Reumont, J.W. Waegele and B. Misof. 2010. Parametric and non-parametric masking of randomness in sequence alignments can be improved and leads to better resolved trees. Frontiers in Zoology 7: 10.
mafft and prank for multiple sequence
alignment; gblocks for another alignment masking algorithm.
data(ips.28S)
if (FALSE) aliscore(ips.28S)
Run the code above in your browser using DataLab