aperm.DNAbin: Array Transposition for DNAbin

View source: R/aperm.DNAbin.R

aperm.DNAbinR Documentation

Array Transposition for DNAbin

Description

S3 method for aperm on objects of class DNAbin. Strips the class before permuting so that apply receives a plain raw matrix from the internal aperm call, matching the behaviour of aperm.default prior to R-devel revision 90136 (2026-06-12).

Usage

## S3 method for class 'DNAbin'
aperm(a, perm = NULL, resize = TRUE, ...)

Arguments

a

A matrix of class DNAbin.

perm

An integer vector giving the permutation of the dimensions.

resize

Logical; passed to aperm.default.

...

Further arguments passed to aperm.default.

Value

A raw matrix without the DNAbin class.


ips documentation built on July 8, 2026, 5:07 p.m.