powered by
A collection of parameter nodes used in the standard template of BEAST2.
beastLog(l, x, i)
An object of class XMLNode.
XMLNode
A character string giving the name (i.e. id or idref attribute) of the desired parameter.
id
idref
A list, internally generated by rbeauti.
rbeauti
Integer giving the index to a partition, internally generated by rbeauti.