Learn R Programming

ips (version 0.0.13)

code.simple.gaps: Simple Gap/Indel Coding

Description

code.simple.gaps takes an aligned DNA sequence matrix and codes the simple gaps, i.e. gaps that do not overlap with other gaps. The gapped positions are excluded from the matrix and the coded gap characters are appended to the matrix.

Usage

code.simple.gaps(x, append = TRUE)

Value

An object of class DNAbin.

Arguments

x

An object of class DNAbin.

append

Logical.

Author

Christoph Heibl

References

Simmons, M.P. & H. Ochoterena. 2000. Gaps as characters in sequence-based phylogenetic analyses. Systematic Biology 49(2): 369--381.

See Also

deleteGaps, deleteEmptyCells, trimEnds