Learn R Programming

ips (version 0.0.13)

forceEqualTipHeights: Equal Tip Heights

Description

Modify terminal edge lengths to create "exactly" (see Details) equal tip heights (sum of edge lengths from root to tip)

Usage

forceEqualTipHeights(phy, baseline = "mean")

Value

An object of class phylo with changed terminal edge lengths.

Arguments

phy

An object of class phylo.

baseline

A character string giving a function to calculate the baseline tip height, e.g. "min", "max" or "mean".

Details

What is "exactly" equal depends on the precision of the system (.Machine); in any case the resulting phylogeny will pass is.ultrametric with default arguments.

See Also

tipHeights