Learn R Programming

ips (version 0.0.13)

mrbayes.lset: Model Settings for MrBayes

Description

Set model parameters for mrbayes.

Usage

mrbayes.lset(..., partition)

Value

a list containing a subset (including the empty and the full set) of model parameters.

Arguments

...

arguments in tag = value form, or a list of tagged values. The tags must come from the names of model parameters described in the ‘Model Parameters’ section.

partition

a character string giving the labelling for a partion.

Model Parameters

nucmodel

"4by4", "doublet", "codon", or "protein".

nst

1, 2, 6, or "mixed".

code

"universal", "vertmt", "mycoplasma", "yeast", "ciliates", or "metmt".

ploidy

"haploid", "diploid", or "zlinked".

rates

"equal", "gamma", "propinv","invgamma", or "adgamma".

ngammacat

1-24

nbetacat

1-24

omegavar

"equal", "ny98", or "m3".

covarion

"no" or "yes".

coding

"all", "variable", "noabsencesites", or "nopresencesites".

parsmodel

"no" or "yes".

Author

Christoph Heibl

References

J.P. Huelsenbeck & Ronquist F. 2001. MrBayes: Bayesian inference of phylogenetic trees. Bioinformatics 17: 754-755.

Ronquist F. & J.P. Huelsenbeck. 2003. MrBayes 3: Bayesian phylogenetic inference under mixed models. Biometrics 19: 1572-1574.

MrBayes website: https://mrbayes.sourceforge.net/.

See Also

mrbayes.prset to set prior distributions, mrbayes.mcmc to set parameters of the Markov chain Monte Carlo (MCMC), and mrbayes to run MrBayes locally or prepare input files for a computer cluster.

Examples

Run this code
## F81
mrbayes.lset(nst = 2)

## GTR + Gamma
mrbayes.lset(nst = 6, rates = "gamma")

## GTR + Gamma + I
mrbayes.lset(nst = 6, rates = "invgamma")

Run the code above in your browser using DataLab