Set Markov chain Monte Carlo (MCMC) parameters for mrbayes.
mrbayes.mcmc(...)a list containing a subset (including the empty and the full set) of model parameters.
arguments in tag = value form, or a list of tagged values. The tags must come from the names of MCMC parameters described in the ‘MCMC Parameters’ section.
"NUMERIC"
"NUMERIC"
"NUMERIC"
"NUMERIC"
% # reweight <number>,<number> 0.00 v 0.00 ^,
"NUMERIC"
"NUMERIC"
"NUMERIC"
"NUMERIC"
"yes" or "no"
"NUMERIC"
"yes" or "no"
"NUMERIC"
"avgstddev" or "maxstddev"
"NUMERIC"
"yes" or "no"
"yes" or "no"
"yes" or "no"
"NUMERIC"
"NUMERIC"
"yes" or "no"
"NUMERIC"
"yes" or "no"
"yes" or "no"
"NUMERIC"
% # filename = filename,
"current" or "reset"
"current", "random", or "parsimony"
"NUMERIC"
"yes" or "no"
"yes" or "no"
"yes" or "no"
"yes" or "no"
"NUMERIC"
Christoph Heibl
J.P. Huelsenbeck & Ronquist F. 2001. MrBayes: Bayesian inference of phylogenetic trees. Bioinformatics 17: 754-755.
Ronquist F. & J.P. Huelsenbeck. 2003. MrBayes 3: Bayesian phylogenetic inference under mixed models. Biometrics 19: 1572-1574.
MrBayes website: https://mrbayes.sourceforge.net/.
mrbayes.lset to set model parameters, mrbayes.prset to set prior distributions, and mrbayes to run MrBayes locally or prepare input files for a computer cluster.