Learn R Programming

ips (version 0.0.13)

mrbayes.prset: Set Priors for MrBayes

Description

Set prior distributions for mrbayes.

Usage

mrbayes.prset(...)

Value

a list of length zero (see 'Note')

Arguments

...

arguments in tag = value form, or a list of tagged values. The tags must come from the names of prior distribution parameters described in the ‘Prior Distribution Parameters’ section.

Prior Distribution Parameters

traitiopr

revmatpr

aamodelpr

aarevmatpr

omegapr

ny98omega1pr

ny98omega3pr

m3omegapr

codoncatfreqs

statefreqpr

shapepr

ratecorrpr

pinvarpr

covswitchpr

symdirihyperpr

topologypr

brlenspr

clockvarpr

igrvarpr

Author

Christoph Heibl

References

J.P. Huelsenbeck & Ronquist F. 2001. MrBayes: Bayesian inference of phylogenetic trees. Bioinformatics 17: 754-755.

Ronquist F. & J.P. Huelsenbeck. 2003. MrBayes 3: Bayesian phylogenetic inference under mixed models. Biometrics 19: 1572-1574.

MrBayes website: https://mrbayes.sourceforge.net/.

See Also

mrbayes.lset to set model parameters, mrbayes.mcmc to set parameters of the Markov chain Monte Carlo (MCMC), and mrbayes to run MrBayes locally or prepare input files for a computer cluster.

Examples

Run this code
mrbayes.prset()

Run the code above in your browser using DataLab