Learn R Programming

ips (version 0.0.13)

pathd8: PATHd8

Description

This function is a wrapper for PATHd8 and can be used for phylogenetic dating, especially of large trees

Usage

pathd8(phy, exec = "/Applications/PATHd8/PATHd8", seql, calibration)

Value

tree list of ultrametric trees returned from PATHd8 of class

phylo. First tree is PATHd8 chronogram, which is a calibrated ultrametric tree. Second is a PATH tree, which is a ultrametric tree without calibration.

Arguments

phy

An object of class phylo.

exec

A character string giving the path to the PATHd8 program.

seql

sequence length of alignment

calibration

A data frame with 4 columns and as many rows as calibration points. Columns are: taxon 1; taxon 2; one of c("minage", "maxage", "fixage"); age.

Author

Franz-Sebastian Krah

References

Britton et al (2006). PATHd8---a new method for estimating divergence times in large phylogenetic trees without a molecular clock. Available from the authors (www.math.su.se/PATHd8)

Britton et al. (2007). Estimating divergence times in large phylogenetic trees. Systematic biology. 56:741--752