Learn R Programming

ips (version 0.0.13)

prank: PRANK

Description

DNA sequence Alignment Using the program PRANK.

Usage

prank(x, outfile, guidetree = NULL, gaprate = 0.025, 
    gapext = 0.75, path)

Value

matrix of class "DNAbin"

Arguments

x

an object of class DNAbin.

outfile

a character string giving a name for the output file.

guidetree

an object of class phylo to be used as guidetree in alignment.

gaprate

numeric giving the gap opening rate; defaults to 0.025.

gapext

numeric giving the gap extension penalty; defaults to 0.75.

path

a character string indicating the path to the PRANK executable.

References

http://wasabiapp.org/software/prank/

See Also

read.fas to import DNA sequences; mafft for another alignment algorithm; gblocks and aliscore for alignment cleaning.