- ...
One or more object(s) of class DNAbin.
- file
A connection, or a character string naming the file to write to.
If left empty the XML tree will be printed to the screen (see Examples).
- template
Currently unused.
- link.clocks
Logical, indicating if clock models should be linked over partitions.
- link.trees
Logical, indicating if tree models should be linked over partitions.
- subst.model
A character string defining a substituion model, either
"JC69", "HKY","TN93", or "GTR".
- clock
A character string defining a clock model, either "Strict
Clock", "Relaxed Clock Exponential","Relaxed Clock Log
Normal", or "Random Local Clock".
- tree
A character string defining a tree model.
- taxonset
A list containing one or more taxon sets.
- chain.length
Integer, the number of generations to run the MCMC.
- log.every
Integer, defining how often samples from the posterior will
be written to log files and shown on screen.