Thess functions parse chronograms in NEXUS format as produced by TreeAnnotator or output by MrBayes.
read.mrbayes(file, digits = NULL)read.beast(file, digits = NULL)
read.starbeast(file)
An object of class phylo.
A character string giving the input file, which must be a TreeAnnotator-generated chronogram in NEXUS format.
NULL or integer, if !is.null(digits) values are rounded to the given integer.
Christoph Heibl
TreeAnnotator: http://beast.community/treeannotator
Metacomments in NEXUS: https://code.google.com/archive/p/beast-mcmc/wikis/NexusMetacommentFormat.wiki
read.beast.table to extract internal node data from NEXUS file, rbeauti to create XML input for BEAST. HPDbars for plotting highest posterior densities on phylogenies has been moved to package viper.