splitIntoClades: Find Monophyletic Subsets in Species Lists
Description
Takes a phylogeny and a subset of its tiplabels
and splits the list of tiplabels into monophyletic groups
(clades).
Usage
splitIntoClades(phy, tips)
Arguments
- phy
An object of class phylo.
- tips
A vector of mode "character" containing any
subset of the tiplabels in phy.