terminalSisters: Find Pairs of Sister Species

View source: R/terminalSisters.R

terminalSistersR Documentation

Find Pairs of Sister Species

Description

Finds pairs of sister species in a phylogenetic tree.

Usage

terminalSisters(phy, labels = TRUE)

Arguments

phy

An object of class phylo.

labels

Logical, indicating whether to return tip labels or tip numbers.

Value

A list of which each element contains the tip labels of a sister species pair.

Examples

set.seed(1234)
tr <- rtree(12)
plot(tr)
terminalSisters(tr)

ips documentation built on July 8, 2026, 5:07 p.m.