Learn R Programming

ips (version 0.0.13)

tipHeights: Tip Heights in a Phylogenetic Tree

Description

For each tip (leave, terminal node) in the phylogenetic tree the edge lengths (branch lengths) from root to tip, be it units of time or divergence, is summed up.

Usage

tipHeights(phy)

Value

a numeric vector with distances from root to tip for each tip in the phylogenetic tree.

Arguments

phy

an object of class phylo.

Author

Christoph Heibl

See Also

branching.times