| aperm.DNAbin | R Documentation |
S3 method for aperm on objects of class
DNAbin. Strips the class before permuting so that
apply receives a plain raw matrix from the internal
aperm call, matching the behaviour of aperm.default prior to
R-devel revision 90136 (2026-06-12).
## S3 method for class 'DNAbin'
aperm(a, perm = NULL, resize = TRUE, ...)
a |
A matrix of class |
perm |
An integer vector giving the permutation of the dimensions. |
resize |
Logical; passed to |
... |
Further arguments passed to |
A raw matrix without the DNAbin class.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.