Learn R Programming

ips (version 0.1.1)

aperm.DNAbin: Array Transposition for DNAbin

Description

S3 method for aperm on objects of class DNAbin. Strips the class before permuting so that apply receives a plain raw matrix from the internal aperm call, matching the behaviour of aperm.default prior to R-devel revision 90136 (2026-06-12).

Usage

# S3 method for DNAbin
aperm(a, perm = NULL, resize = TRUE, ...)

Value

A raw matrix without the DNAbin class.

Arguments

a

A matrix of class DNAbin.

perm

An integer vector giving the permutation of the dimensions.

resize

Logical; passed to aperm.default.

...

Further arguments passed to aperm.default.