S3 method for aperm on objects of class
DNAbin. Strips the class before permuting so that
apply receives a plain raw matrix from the internal
aperm call, matching the behaviour of aperm.default prior to
R-devel revision 90136 (2026-06-12).
# S3 method for DNAbin
aperm(a, perm = NULL, resize = TRUE, ...)A raw matrix without the DNAbin class.
A matrix of class DNAbin.
An integer vector giving the permutation of the dimensions.
Logical; passed to aperm.default.
Further arguments passed to aperm.default.