View source: R/collapseUnsupportedEdges.R
| collapseUnsupportedEdges | R Documentation |
Given a set of node support values (e.g., bootstrap proportions, posterior probabilities) and a certain threshold, all edges receiving less support than the threshold will be collapsed.
collapseUnsupportedEdges(phy, value = "node.label", cutoff)
phy |
An object of class |
value |
A character string giving the name of the list element of the
|
cutoff |
A numeric value giving the threshold below which edges will be collapsed. |
Collapsing weekly supported edges can help draw attention to those parts of a phylogeny that are really supported by the underlying data.
An object of class phylo.
## phylogeny of bark beetles
data(ips.tree)
## non-parametric bootstrap proportions (BP)
ips.tree$node.label
## collapse clades with < 70 BP
tr <- collapseUnsupportedEdges(ips.tree, "node.label", 70)
## show new topology
plot(tr, no.margin = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.