arguments in tag = value form, or a list of tagged values. The tags must come from the names of prior distribution parameters described in the ‘Prior Distribution Parameters’ section.
Prior Distribution Parameters
traitiopr
revmatpr
aamodelpr
aarevmatpr
omegapr
ny98omega1pr
ny98omega3pr
m3omegapr
codoncatfreqs
statefreqpr
shapepr
ratecorrpr
pinvarpr
covswitchpr
symdirihyperpr
topologypr
brlenspr
clockvarpr
igrvarpr
Author
Christoph Heibl
References
J.P. Huelsenbeck & Ronquist F. 2001. MrBayes: Bayesian inference of phylogenetic trees. Bioinformatics17: 754-755.
Ronquist F. & J.P. Huelsenbeck. 2003. MrBayes 3: Bayesian phylogenetic inference under mixed models. Biometrics19: 1572-1574.
mrbayes.lset to set model parameters, mrbayes.mcmc to set parameters of the Markov chain Monte Carlo (MCMC), and mrbayes to run MrBayes locally or prepare input files for a computer cluster.