Learn R Programming

ips (version 0.0.13)

terminalSisters: Find Pairs of Sister Species

Description

Finds pairs of sister species in a phylogenetic tree.

Usage

terminalSisters(phy, labels = TRUE)

Value

A list of which each element contains the tip labels of a sister species pair.

Arguments

phy

An object of class phylo.

labels

Logical, indicating whether to return tip labels or tip numbers.

Examples

Run this code
set.seed(1234)
tr <- rtree(12)
plot(tr)
terminalSisters(tr)

Run the code above in your browser using DataLab