powered by
Finds pairs of sister species in a phylogenetic tree.
terminalSisters(phy, labels = TRUE)
A list of which each element contains the tip labels of a sister species pair.
An object of class phylo.
phylo
Logical, indicating whether to return tip labels or tip numbers.
set.seed(1234) tr <- rtree(12) plot(tr) terminalSisters(tr)
Run the code above in your browser using DataLab